// src/search/plugin.ts
import { sources, webpack } from "next/dist/compiled/webpack/webpack";
import { IS_PRODUCTION } from "../constants.mjs";
var NextraSearchPlugin = class {
  apply(compiler) {
    const pluginName = this.constructor.name;
    compiler.hooks.make.tap(pluginName, (compilation) => {
      compilation.hooks.processAssets.tap(
        {
          name: pluginName,
          stage: webpack.Compilation.PROCESS_ASSETS_STAGE_ADDITIONS
        },
        (assets) => {
          const indexFiles = {};
          for (const [, entry] of compilation.entries.entries()) {
            const entryDependency = entry.dependencies?.[0];
            let entryModule = compilation.moduleGraph.getResolvedModule(entryDependency);
            if (!entryModule?.buildInfo?.nextraSearch) {
              for (const dependency of entryModule.dependencies) {
                const mod = compilation.moduleGraph.getResolvedModule(dependency);
                if (mod?.buildInfo?.nextraSearch) {
                  entryModule = mod;
                }
              }
            }
            const nextraSearch = entryModule?.buildInfo?.nextraSearch;
            if (nextraSearch) {
              const { title, data, indexKey, route } = nextraSearch;
              const indexFilename = `nextra-data-${indexKey}.json`;
              if (indexFiles[indexFilename] === void 0) {
                indexFiles[indexFilename] = "{";
              }
              if (indexFiles[indexFilename] !== "{") {
                indexFiles[indexFilename] += ",";
              }
              const payload = {
                [route]: { title, data }
              };
              indexFiles[indexFilename] += JSON.stringify(payload).slice(1, -1);
            }
          }
          for (const [file, content] of Object.entries(indexFiles)) {
            assets[`${IS_PRODUCTION ? "../" : ""}../static/chunks/${file}`] = new sources.RawSource(content + "}");
          }
        }
      );
    });
  }
};
export {
  NextraSearchPlugin
};
